define('dojo/nls/pmbdijit_ru',{
'dijit/nls/loading':{"loadingState":"Загрузка...","errorState":"Извините, возникла ошибка","_localized":{}}
,
'dijit/form/nls/validate':{"invalidMessage":"Указано недопустимое значение.","missingMessage":"Это обязательное значение.","rangeMessage":"Это значение вне диапазона.","_localized":{}}
,
'dojo/cldr/nls/number':{"scientificFormat":"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]","infinity":"∞","superscriptingExponent":"×","list":";","percentSign":"%","minusSign":"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000 трлн","currencySpacing-afterCurrency-insertBetween":" ","nan":"не число","plusSign":"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]","currencyFormat":"#,##0.00 ¤","perMille":"‰","group":" ","percentFormat":"#,##0 %","decimalFormat-long":"000 триллиона","decimalFormat":"#,##0.###","decimal":",","currencySpacing-beforeCurrency-insertBetween":" ","exponential":"E","_localized":{}}
,
'dijit/nls/common':{"buttonOk":"OK","buttonCancel":"Отмена","buttonSave":"Сохранить","itemClose":"Закрыть","_localized":{}}
,
'dijit/_editor/nls/commands':{"bold":"Полужирный","copy":"Копировать","cut":"Вырезать","delete":"Удалить","indent":"Отступ","insertHorizontalRule":"Горизонтальная линейка","insertOrderedList":"Нумерованный список","insertUnorderedList":"Список с маркерами","italic":"Курсив","justifyCenter":"Выровнять по центру","justifyFull":"По ширине","justifyLeft":"Выровнять по левому краю","justifyRight":"Выровнять по правому краю","outdent":"Втяжка","paste":"Вставить","redo":"Повторить","removeFormat":"Удалить формат","selectAll":"Выбрать все","strikethrough":"Перечеркивание","subscript":"Нижний индекс","superscript":"Верхний индекс","underline":"Подчеркивание","undo":"Отменить","unlink":"Удалить ссылку","createLink":"Создать ссылку","toggleDir":"Изменить направление","insertImage":"Вставить изображение","insertTable":"Вставить/изменить таблицу","toggleTableBorder":"Переключить рамку таблицы","deleteTable":"Удалить таблицу","tableProp":"Свойства таблицы","htmlToggle":"Код HTML","foreColor":"Цвет текста","hiliteColor":"Цвет фона","plainFormatBlock":"Стиль абзаца","formatBlock":"Стиль абзаца","fontSize":"Размер шрифта","fontName":"Название шрифта","tabIndent":"Табуляция","fullScreen":"Переключить полноэкранный режим","viewSource":"Показать исходный код HTML","print":"Печать","newPage":"Создать страницу","systemShortcut":"Действие \"${0}\" можно выполнить в браузере только путем нажатия клавиш ${1}.","ctrlKey":"ctrl+${0}","appleKey":"⌘${0}","_localized":{}}
,
'dijit/form/nls/ComboBox':{"previousMessage":"Предыдущие варианты","nextMessage":"Следующие варианты","_localized":{}}
,
'dijit/_editor/nls/FontChoice':{"1":"самый маленький","2":"очень маленький","3":"маленький","4":"средний","5":"большой","6":"очень большой","7":"самый большой","fontSize":"Размер","fontName":"Шрифт","formatBlock":"Формат","serif":"с засечками","sans-serif":"без засечек","monospace":"непропорциональный","cursive":"курсив","fantasy":"артистический","noFormat":"Нет","p":"Абзац","h1":"Заголовок","h2":"Подзаголовок","h3":"Вложенный подзаголовок","pre":"Заранее отформатированный","_localized":{}}
,
'dojox/editor/plugins/nls/latinEntities':{"iexcl":"инвертированный восклицательный знак","cent":"символ цента","pound":"символ фунта стерлингов","curren":"символ денежной единицы","yen":"символ иены\nсимвол юаня","brvbar":"прерывистая черта\nвертикальная прерывистая черта","sect":"символ раздела","uml":"трема\nтрема с интервалом","copy":"символ авторских прав","ordf":"индикатор женского рода","laquo":"левые двойные угловые кавычки\nлевые кавычки","not":"знак отрицания","shy":"мягкий перенос\nвозможный перенос","reg":"символ Зарегистрирован\nсимвол зарегистрированного товарного знака","macr":"знак долготы\nзнак долготы с интервалом\nверхняя черта\nнадчеркивание APL","deg":"символ градусов","plusmn":"символ плюс-минус\nсимвол плюса или минуса","sup2":"верхний индекс два\nверхний индекс с цифрой два\nвозведение в квадрат","sup3":"верхний индекс три\nверхний индекс с цифрой три\nвозведение в куб","acute":"знак акут\nакут с интервалом","micro":"знак микро","para":"символ абзаца\nсимвол параграфа","middot":"средняя точка\nзапятая в грузинском\nсредняя точка в греческом","cedil":"седиль\nседиль с интервалом","sup1":"верхний индекс один\nверхний индекс с цифрой один","ordm":"индикатор мужского рода","raquo":"правая двойная угловая кавычка\nправая кавычка","frac14":"дробь одна четвертая\nодна четверть","frac12":"дробь одна вторая\nодна вторая","frac34":"дробь три четверти\nтри четверти","iquest":"инвертированный знак вопроса\nперевернутый знак вопроса","Agrave":"латинская прописная буква A с грависом","Aacute":"латинская прописная буква A с акутом","Acirc":"латинская прописная буква A с циркумфлексом","Atilde":"латинская прописная буква A с тильдой","Auml":"латинская прописная буква A с тремой","Aring":"латинская прописная буква A с кружком сверху\nлатинская прописная буква A с кружком","AElig":"латинская прописная буква AE\nлатинская прописная лигатура AE","Ccedil":"латинская прописная буква C с седилью","Egrave":"латинская прописная буква E с грависом","Eacute":"латинская прописная буква E с акутом","Ecirc":"латинская прописная буква E с циркумфлексом","Euml":"латинская прописная буква E с тремой","Igrave":"латинская прописная буква I с грависом","Iacute":"латинская прописная буква I с акутом","Icirc":"латинская прописная буква I с циркумфлексом","Iuml":"латинская прописная буква I с тремой","ETH":"латинская прописная буква ETH","Ntilde":"латинская прописная буква N с тильдой","Ograve":"латинская прописная буква O с грависом","Oacute":"латинская прописная буква O с акутом","Ocirc":"латинская прописная буква O с циркумфлексом","Otilde":"латинская прописная буква O с тильдой","Ouml":"латинская прописная буква O с тремой","times":"знак умножения","Oslash":"латинская прописная буква O перечеркнутая\nлатинская прописная буква O с вертикальной чертой","Ugrave":"латинская прописная буква U с грависом","Uacute":"латинская прописная буква U с акутом","Ucirc":"латинская прописная буква U с циркумфлексом","Uuml":"латинская прописная буква U с тремой","Yacute":"латинская прописная буква Y с акутом","THORN":"латинская прописная буква THORN","szlig":"латинская строчная заостренная эсцэт","agrave":"латинская строчная буква a с грависом\nлатинская строчная a с грависом","aacute":"латинская строчная буква a с акутом","acirc":"латинская строчная буква a с циркумфлексом","atilde":"латинская строчная буква a с тильдой","auml":"латинская строчная буква a с тремой","aring":"латинская строчная буква a с кружком сверху\nлатинская строчная a с кружком","aelig":"латинская строчная буква ae\nлатинская строчная лигатура ae","ccedil":"латинская строчная буква c с седилью","egrave":"латинская строчная буква e с грависом","eacute":"латинская строчная буква e с акутом","ecirc":"латинская строчная буква e с циркумфлексом","euml":"латинская строчная буква e с тремой","igrave":"латинская строчная буква i с грависом","iacute":"латинская строчная буква i с акутом","icirc":"латинская строчная буква i с циркумфлексом","iuml":"латинская строчная буква i с тремой","eth":"латинская строчная буква eth","ntilde":"латинская строчная буква n с тильдой","ograve":"латинская строчная буква o с грависом","oacute":"латинская строчная буква o с акутом","ocirc":"латинская строчная буква o с циркумфлексом","otilde":"латинская строчная буква o с тильдой","ouml":"латинская строчная буква o с тремой","divide":"знак деления","oslash":"латинская строчная буква o перечеркнутая\nлатинская строчная буква o с вертикальной чертой","ugrave":"латинская строчная буква u с грависом","uacute":"латинская строчная буква u с акутом","ucirc":"латинская строчная буква u с циркумфлексом","uuml":"латинская строчная буква u с тремой","yacute":"латинская строчная буква y с акутом","thorn":"латинская строчная буква thorn","yuml":"латинская строчная буква y с тремой","fnof":"латинская строчная буква f с хвостиком\nфункция\nфлорин","Alpha":"греческая прописная буква альфа","Beta":"греческая прописная буква бета","Gamma":"греческая прописная буква гамма","Delta":"греческая прописная буква дельта","Epsilon":"греческая прописная буква эпсилон","Zeta":"греческая прописная буква дзета","Eta":"греческая прописная буква эта","Theta":"греческая прописная буква тета","Iota":"греческая прописная буква йота","Kappa":"греческая прописная буква каппа","Lambda":"греческая прописная буква лямбда","Mu":"греческая прописная буква мю","Nu":"греческая прописная буква ню","Xi":"греческая прописная буква кси","Omicron":"греческая прописная буква омикрон","Pi":"греческая прописная буква пи","Rho":"греческая прописная буква ро","Sigma":"греческая прописная буква сигма","Tau":"греческая прописная буква тау","Upsilon":"греческая прописная буква ипсилон","Phi":"греческая прописная буква фи","Chi":"греческая прописная буква хи","Psi":"греческая прописная буква пси","Omega":"греческая прописная буква омега","alpha":"греческая строчная буква альфа","beta":"греческая строчная буква бета","gamma":"греческая строчная буква гамма","delta":"греческая строчная буква дельта","epsilon":"греческая строчная буква эпсилон","zeta":"греческая строчная буква дзета","eta":"греческая строчная буква эта","theta":"греческая строчная буква тета","iota":"греческая строчная буква йота","kappa":"греческая строчная буква каппа","lambda":"греческая строчная буква лямбда","mu":"греческая строчная буква мю","nu":"греческая строчная буква ню","xi":"греческая строчная буква хи","omicron":"греческая строчная буква омикрон","pi":"греческая строчная буква пи","rho":"греческая строчная буква ро","sigmaf":"греческая строчная конечная сигма","sigma":"греческая строчная буква сигма","tau":"греческая строчная буква тау","upsilon":"греческая строчная буква ипсилон","phi":"греческая строчная буква фи","chi":"греческая строчная буква хи","psi":"греческая строчная буква пси","omega":"греческая строчная буква омега","thetasym":"греческая символьная тета","upsih":"греческий ипсилон с хвостиком","piv":"греческая символьная пи","bull":"маркер списка\nчерный маленький кружок","hellip":"многоточие\nтри точки","prime":"штрих\nминуты\nфуты","Prime":"двойной штрих\nсекунды\nдюймы","oline":"верхняя черта\nнадчеркивание с интервалом","frasl":"косая черта","weierp":"рукописная прописная P\nстепенное множество\nфункции Вейерштрасса","image":"черная прописная I\nмнимая часть","real":"черная прописная R\nвещественная часть","trade":"символ товарного знака","alefsym":"буква Алеф\nкардинальное число","larr":"стрелка влево","uarr":"стрелка вверх","rarr":"стрелка вправо","darr":"стрелка вниз","harr":"стрелка влево-вправо","crarr":"стрелка вниз с углом вправо\nвозврат каретки","lArr":"двойная стрелка влево","uArr":"двойная стрелка вверх","rArr":"двойная стрелка вправо","dArr":"двойная стрелка вниз","hArr":"двойная стрелка влево-вправо","forall":"для всех","part":"частичный дифференциал","exist":"существует","empty":"пустой набор\nпустое множество\nдиаметр","nabla":"оператор набла\nразностное отношение назад","isin":"является элементом","notin":"не является элементом","ni":"содержит в качестве элемента","prod":"n-арное произведение\nсимвол произведения","sum":"n-арное суммирование","minus":"знак минуса","lowast":"оператор звездочка","radic":"квадратный корень\nзнак корня","prop":"пропорционально","infin":"бесконечность","ang":"угол","and":"логическое И\nклин вверх","or":"логическое ИЛИ\nклин вниз","cap":"пересечение\nшапочка","cup":"объединение\nчашечка","int":"интеграл","there4":"следовательно","sim":"оператор тильда\nизменяться с\nподобно","cong":"приблизительно равно","asymp":"почти равно\nасимптотично","ne":"не равно","equiv":"идентично","le":"меньше или равно","ge":"больше или равно","sub":"подмножество","sup":"включает в себя","nsub":"не является подмножеством","sube":"является подмножеством или эквивалентно","supe":"включает в себя или эквивалентно","oplus":"плюс в круге\nпрямая сумма","otimes":"умножение в круге\nвекторное произведение","perp":"перевернутый гвоздь\nортогонально к\nперпендикулярно","sdot":"оператор точка","lceil":"левая скобка округления вверх\nAPL upstile","rceil":"правая скобка округления вверх","lfloor":"левая скобка округления вниз\nAPL downstile","rfloor":"правая скобка округления вниз","lang":"левая угловая скобка","rang":"правая угловая скобка","loz":"ромб","spades":"пики","clubs":"трефы\nтрилистник","hearts":"червы\nвалентинка","diams":"бубны","OElig":"латинская прописная лигатура OE","oelig":"латинская строчная лигатура oe","Scaron":"латинская прописная буква S с галочкой","scaron":"латинская строчная буква s с галочкой","Yuml":"латинская прописная буква Y с тремой","circ":"надстрочный знак циркумфлекс","tilde":"малая тильда","ensp":"пробел длины N","emsp":"пробел длины M","thinsp":"узкий пробел","zwnj":"разделитель нулевой ширины","zwj":"соединитель нулевой ширины","lrm":"знак слева-направо","rlm":"знак справа-налево","ndash":"тире длины N","mdash":"тире длины M","lsquo":"левая одинарная кавычка","rsquo":"правая одинарная кавычка","sbquo":"одиночная нижняя кавычка","ldquo":"левая двойная кавычка","rdquo":"правая двойная кавычка","bdquo":"двойная нижняя кавычка","dagger":"крест","Dagger":"двойной крест","permil":"знак промилле","lsaquo":"одинарная левая угловая кавычка","rsaquo":"одинарная правая угловая кавычка","euro":"символ евро","_localized":{}}
,
'dojox/editor/plugins/nls/InsertEntity':{"insertEntity":"Вставить символ","_localized":{}}
,
'dojo/nls/colors':{"aliceblue":"серо-голубой","antiquewhite":"белый антик","aqua":"зеленовато-голубой","aquamarine":"аквамарин","azure":"лазурный","beige":"бежевый","bisque":"бисквитный","black":"черный","blanchedalmond":"светло-миндальный","blue":"синий","blueviolet":"сине-фиолетовый","brown":"коричневый","burlywood":"светло-коричневый","cadetblue":"серо-синий","chartreuse":"желто-салатный","chocolate":"шоколадный","coral":"коралловый","cornflowerblue":"фиолетово-синий","cornsilk":"шелковый оттенок","crimson":"малиновый","cyan":"циан","darkblue":"темно-синий","darkcyan":"темный циан","darkgoldenrod":"темно-золотистый","darkgray":"темно-серый","darkgreen":"темно-зеленый","darkgrey":"темно-серый","darkkhaki":"темный хаки","darkmagenta":"темно-пурпурный","darkolivegreen":"темно-оливковый","darkorange":"темно-оранжевый","darkorchid":"темный орсель","darkred":"темно-красный","darksalmon":"темно-лососевый","darkseagreen":"темный морской волны","darkslateblue":"темный грифельно-синий","darkslategray":"темный грифельно-серый","darkslategrey":"темный грифельно-серый","darkturquoise":"темный бирюзовый","darkviolet":"темно-фиолетовый","deeppink":"темно-розовый","deepskyblue":"темный небесно-голубой","dimgray":"тускло-серый","dimgrey":"тускло-серый","dodgerblue":"бледно-синий","firebrick":"кирпичный","floralwhite":"цветочно-белый","forestgreen":"зеленый лесной","fuchsia":"фуксин","gainsboro":"бледно-серый","ghostwhite":"призрачно-белый","gold":"золотой","goldenrod":"золотистый","gray":"серый","green":"зеленый","greenyellow":"зелено-желтый","grey":"серый","honeydew":"медовый","hotpink":"красно-розовый","indianred":"индийский красный","indigo":"индиго","ivory":"слоновой кости","khaki":"хаки","lavender":"бледно-лиловый","lavenderblush":"розовато-лиловый","lawngreen":"зеленая лужайка","lemonchiffon":"бледно-лимонный","lightblue":"светло-синий","lightcoral":"светло-коралловый","lightcyan":"светлый циан","lightgoldenrodyellow":"светло-золотистый","lightgray":"светло-серый","lightgreen":"светло-зеленый","lightgrey":"светло-серый","lightpink":"светло-розовый","lightsalmon":"светло-лососевый","lightseagreen":"светлый морской волны","lightskyblue":"светлый небесно-голубой","lightslategray":"светлый грифельно-серый","lightslategrey":"светлый грифельно-серый","lightsteelblue":"светлый стальной","lightyellow":"светло-желтый","lime":"лайм","limegreen":"зеленый лайм","linen":"хлопковый","magenta":"пурпурный","maroon":"темно-бордовый","mediumaquamarine":"нейтральный аквамарин","mediumblue":"нейтральный синий","mediumorchid":"нейтральный орсель","mediumpurple":"нейтральный фиолетовый","mediumseagreen":"нейтральный морской волны","mediumslateblue":"нейтральный грифельно-синий","mediumspringgreen":"нейтральный весенне-зеленый","mediumturquoise":"нейтральный бирюзовый","mediumvioletred":"нейтральный фиолетово-красный","midnightblue":"полуночно-синий","mintcream":"мятно-кремовый","mistyrose":"блекло-розовый","moccasin":"мокасин","navajowhite":"белый навахо","navy":"темно-синий","oldlace":"матово-белый","olive":"оливковый","olivedrab":"желтовато-серый","orange":"оранжевый","orangered":"оранжево-красный","orchid":"орсель","palegoldenrod":"бледно-золотистый","palegreen":"бледно-зеленый","paleturquoise":"бледно-бирюзовый","palevioletred":"бледный фиолетово-красный","papayawhip":"черенок папайи","peachpuff":"персиковый","peru":"перу","pink":"розовый","plum":"сливовый","powderblue":"пороховой","purple":"фиолетовый","red":"красный","rosybrown":"розово-коричневый","royalblue":"королевский голубой","saddlebrown":"кожано-коричневый","salmon":"лососевый","sandybrown":"коричнево-песчаный","seagreen":"морской волны","seashell":"морская раковина","sienna":"охра","silver":"серебристый","skyblue":"небесно-голубой","slateblue":"грифельно-синий","slategray":"грифельно-серый","slategrey":"грифельно-серый","snow":"белоснежный","springgreen":"весенний зеленый","steelblue":"стальной","tan":"рыжевато-коричневый","teal":"чирок","thistle":"чертополох","tomato":"помидор","transparent":"прозрачный","turquoise":"бирюзовый","violet":"фиолетовый","wheat":"пшеница","white":"белый","whitesmoke":"дымчато-белый","yellow":"желтый","yellowgreen":"желто-зеленый","_localized":{}}
,
'dojox/widget/nls/ColorPicker':{"redLabel":"к","greenLabel":"з","blueLabel":"с","hueLabel":"о","saturationLabel":"н","valueLabel":"з","degLabel":"°","hexLabel":"шест","huePickerTitle":"Выбор оттенка","saturationPickerTitle":"Выбор насыщенности","_localized":{}}
,
'dojox/editor/plugins/nls/TableDialog':{"insertTableTitle":"Вставить таблицу","modifyTableTitle":"Изменить таблицу","rows":"Число строк:","columns":"Число столбцов:","align":"Выравнивание:","cellPadding":"Отступ внутри ячеек:","cellSpacing":"Расстояние между ячейками:","tableWidth":"Ширина таблицы:","backgroundColor":"Цвет фона:","borderColor":"Цвет рамки:","borderThickness":"Толщина рамки:","percent":"процентов","pixels":"пикселов","default":"по умолчанию","left":"по левому краю","center":"по центру","right":"по правому краю","buttonSet":"Задать","buttonInsert":"Вставить","buttonCancel":"Отмена","selectTableLabel":"Выбрать таблицу","insertTableRowBeforeLabel":"Добавить строку перед","insertTableRowAfterLabel":"Добавить строку после","insertTableColumnBeforeLabel":"Добавить столбец перед","insertTableColumnAfterLabel":"Добавить столбец после","deleteTableRowLabel":"Удалить строку","deleteTableColumnLabel":"Удалить столбец","colorTableCellTitle":"Цвет фона - ячейка таблицы","tableContextMenuTitle":"Контекстное меню таблицы","_localized":{}}
,
'dojox/editor/plugins/nls/PasteFromWord':{"pasteFromWord":"Вставить из Word","instructions":"Вставить содержимое из Word в текстовое поле ниже.  Когда выберите содержимое для вставки, нажмите кнопку Вставить.  Для отмены вставки текста нажмите кнопку Отмена.","_localized":{}}
,
'dojox/editor/plugins/nls/InsertAnchor':{"insertAnchor":"Вставить метку","title":"Свойства метки","anchor":"Имя:","text":"Описание:","set":"Задать","cancel":"Отмена","_localized":{}}
,
'dojox/editor/plugins/nls/Blockquote':{"blockquote":"Блок цитат","_localized":{}}
,
'dojox/editor/plugins/nls/LocalImage':{"insertImageTitle":"Вставить изображение","url":"Изображение","browse":"Обзор...","text":"Описание","set":"Вставить","invalidMessage":"Недопустимый тип файла изображения","prePopuTextUrl":"Введите URL изображения","prePopuTextBrowse":" или выберите локальный файл.","_localized":{}}
});